@@ -6,12 +6,11 @@ module ProjectIntegrationSpec (spec) where
 
 import Helpers (assertSucceeds, buildTestProject, generateUniqueName, getTestConfig, liftTodoist)
 
-import Web.Todoist.Util.Builder (runBuilder, setDescription)
 import Web.Todoist.Domain.Project
     ( ProjectCreate
-    , ProjectUpdate (..)
     , TodoistProjectM (..)
-    , newProject
+    , createProjectBuilder
+    , updateProjectBuilder
     )
 import qualified Web.Todoist.Domain.Project as P
 import Web.Todoist.Domain.Types
@@ -28,7 +27,9 @@ import Web.Todoist.Internal.Types
     , ProjectPermissions (..)
     , RoleActions (..)
     )
+import Web.Todoist.Lens ((^.))
 import Web.Todoist.Runner (todoist)
+import Web.Todoist.Util.Builder (runBuilder, withDescription, withName, withIsFavorite)
 
 import Control.Exception (bracket)
 import Control.Monad (forM_, mapM, mapM_, void)
@@ -70,31 +71,26 @@ projectLifecycleSpec :: TodoistConfig -> Spec
 projectLifecycleSpec config = describe "Project lifecycle (create, get, delete)" $ do
     it "creates, retrieves, and deletes a project with all fields set" $ do
         -- Generate unique project name
-        newProjectName <- pack <$> generateUniqueName "IntegTest-ProjectLifecycle"
+        createProjectBuilderName <- pack <$> generateUniqueName "IntegTest-ProjectLifecycle"
 
         -- Build a complete project with all fields using the Builder pattern
-        let testProject = buildTestProject newProjectName
+        let testProject = buildTestProject createProjectBuilderName
 
         -- Extract expected values from testProject for verification
-        let P.ProjectCreate
-                { _name = expectedName
-                , _description = expectedDescription
-                , _view_style = expectedViewStyle
-                , _is_favorite = expectedIsFavorite
-                } = testProject
+        let expectedName = testProject ^. P.projectCreateName
+            expectedDescription = testProject ^. P.projectCreateDescription
+            expectedViewStyle = testProject ^. P.projectCreateViewStyle
+            expectedIsFavorite = testProject ^. P.projectCreateIsFavorite
 
         -- Use withTestProjectCreate to handle creation and cleanup
         withTestProjectCreate config testProject $ \projectId -> do
             -- Get the project by ID and verify all fields
             project <- liftTodoist config (getProject projectId)
-
-            let P.Project
-                    { _id = projId
-                    , _name = projName
-                    , _description = projDescription
-                    , _view_style = projViewStyle
-                    , _is_favorite = projIsFavorite
-                    } = project
+            let projId = project ^. P.projectId
+                projName = project ^. P.name
+                projDescription = project ^. P.description
+                projViewStyle = project ^. P.viewStyle
+                projIsFavorite = project ^. P.isFavorite
 
             -- Verify the project details match expected values
             liftIO $ projId `shouldBe` projectId
@@ -287,7 +283,7 @@ updateProjectSpec config = describe "Update project" $ do
         let updatedDescription = "Updated description"
 
         -- Create initial project with specific properties
-        let initialProject = runBuilder (newProject originalName) (setDescription originalDescription)
+        let initialProject = runBuilder (createProjectBuilder originalName) (withDescription originalDescription)
 
         withTestProjectCreate config initialProject $ \projectId -> do
             -- Verify initial state
@@ -296,18 +292,11 @@ updateProjectSpec config = describe "Update project" $ do
                 let P.Project {P._name = proj1Name, P._description = proj1Desc, P._is_favorite = proj1Fav} = project1
                 proj1Name `shouldBe` Name originalName
                 proj1Desc `shouldBe` Description originalDescription
-                proj1Fav `shouldBe` IsFavorite False -- default from newProject
+                proj1Fav `shouldBe` IsFavorite False -- default from createProjectBuilder
 
             -- Update the project (change name, description, and favorite status)
             let updatedName = originalName <> "-Updated"
-            let projectUpdate =
-                    ProjectUpdate
-                        { _name = Just (Name updatedName)
-                        , _description = Just (Description updatedDescription)
-                        , _color = Nothing -- don't change color
-                        , _is_favorite = Just (IsFavorite True)
-                        , _view_style = Nothing -- don't change view style
-                        }
+            let projectUpdate = runBuilder updateProjectBuilder (withName updatedName <> withDescription updatedDescription <> withIsFavorite True)
 
             updatedProject <- liftTodoist config (updateProject projectUpdate projectId)
 
@@ -346,7 +335,7 @@ updateProjectSpec config = describe "Update project" $ do
         let initialDescription = "Initial description"
 
         -- Create initial project
-        let initialProject = runBuilder (newProject projectName) (setDescription initialDescription)
+        let initialProject = runBuilder (createProjectBuilder projectName) (withDescription initialDescription)
 
         withTestProjectCreate config initialProject $ \projectId -> do
             -- Get initial state
@@ -354,14 +343,7 @@ updateProjectSpec config = describe "Update project" $ do
             let P.Project {P._description = originalDescription} = project1
 
             -- Partial update: only change is_favorite
-            let partialUpdate =
-                    ProjectUpdate
-                        { _name = Nothing
-                        , _description = Nothing
-                        , _color = Nothing
-                        , _is_favorite = Just (IsFavorite True)
-                        , _view_style = Nothing
-                        }
+            let partialUpdate = runBuilder updateProjectBuilder (withIsFavorite True)
 
             updatedProject <- liftTodoist config (updateProject partialUpdate projectId)
 
@@ -398,7 +380,7 @@ withTestProject :: TodoistConfig -> Text -> (ProjectId -> ExceptT TodoistError I
 withTestProject config projectName action = do
     let createProject = do
             liftIO $ putStrLn $ "Creating test project: " <> show projectName
-            liftTodoist config (addProject $ runBuilder (newProject projectName) mempty)
+            liftTodoist config (addProject $ runBuilder (createProjectBuilder projectName) mempty)
 
     let deleteProject' projectId = do
             liftIO $ putStrLn $ "Cleaning up test project: " <> show projectName
@@ -416,7 +398,7 @@ withTestProjects :: TodoistConfig -> [Text] -> ([ProjectId] -> ExceptT TodoistEr
 withTestProjects config projectNames action = do
     let createProjects = do
             liftIO $ putStrLn $ "Creating " <> show (L.length projectNames) <> " test projects"
-            mapM (\name -> liftTodoist config (addProject $ runBuilder (newProject name) mempty)) projectNames
+            mapM (\name -> liftTodoist config (addProject $ runBuilder (createProjectBuilder name) mempty)) projectNames
 
     let deleteProjects projectIds = do
             liftIO $ putStrLn $ "Cleaning up " <> show (L.length projectIds) <> " test projects"
