@@ -44,14 +44,14 @@ module Web.Todoist
     , TodoistLabelM (..)
 
       -- * Project Types
-    , Project (..)
+    , Project
     , ProjectCreate
     , ProjectUpdate
-    , Collaborator (..)
+    , Collaborator
     , PaginationParam (..)
-    , newProject
-    , emptyProjectUpdate
-    , newPaginationParam
+    , createProjectBuilder
+    , updateProjectBuilder
+    , paginationParamBuilder
     , IsShared (..)
     , IsArchived (..)
     , CanAssignTasks (..)
@@ -60,8 +60,8 @@ module Web.Todoist
     , Task (..)
     , TaskParam (..)
     , NewTask (..)
-    , MoveTask (..)
-    , newTaskParam
+    , MoveTask
+    , taskParamBuilder
 
       -- * Comment Types
     , Comment (..)
@@ -69,9 +69,9 @@ module Web.Todoist
     , CommentCreate
     , CommentUpdate
     , CommentParam (..)
-    , newComment
-    , newCommentUpdate
-    , newCommentParam
+    , newCommentBuilder
+    , updateCommentBuilder
+    , commentParamBuilder
 
       -- * Section Types
     , Section (..)
@@ -79,9 +79,9 @@ module Web.Todoist
     , SectionCreate
     , SectionUpdate
     , SectionParam (..)
-    , newSection
-    , emptySectionUpdate
-    , newSectionParam
+    , newSectionBuilder
+    , updateSectionBuilder
+    , sectionParamBuilder
 
       -- * Label Types
     , Label (..)
@@ -92,10 +92,12 @@ module Web.Todoist
     , SharedLabelParam (..)
     , SharedLabelRename
     , SharedLabelRemove
-    , newLabel
-    , emptyLabelUpdate
-    , newLabelParam
-    , newSharedLabelParam
+    , createLabelBuilder
+    , updateLabelBuilder
+    , labelParamBuilder
+    , sharedLabelParamBuilder
+    , mkSharedLabelRename
+    , mkSharedLabelRemove
 
       -- * Common Domain Types
     , ProjectId (..)
@@ -114,24 +116,25 @@ module Web.Todoist
     , Initial
     , runBuilder
     , seed
-    , setName
-    , setDescription
-    , setIsFavorite
-    , setViewStyle
-    , setParentId
-    , setProjectId
-    , setSectionId
-    , setContent
-    , setPriority
-    , setDueString
-    , setDueDate
-    , setDueDatetime
-    , setDueLang
-    , setAssigneeId
-    , setLabels
-    , setWorkspaceId
-    , setOrder
-    , setTaskId
+    , withName
+    , withDescription
+    , withIsFavorite
+    , withViewStyle
+    , withParentId
+    , withProjectId
+    , withSectionId
+    , withContent
+    , withColor
+    , withPriority
+    , withDueString
+    , withDueDate
+    , withDueDatetime
+    , withDueLang
+    , withAssigneeId
+    , withLabels
+    , withWorkspaceId
+    , withOrder
+    , withTaskId
     ) where
 
 import Web.Todoist.Runner
@@ -150,26 +153,26 @@ import Web.Todoist.Internal.Error (TodoistError (..))
 
 import Web.Todoist.Domain.Project
     ( CanAssignTasks (..)
-    , Collaborator (..)
+    , Collaborator
     , IsArchived (..)
     , IsShared (..)
     , PaginationParam (..)
-    , Project (..)
+    , Project
     , ProjectCreate
     , ProjectUpdate
     , TodoistProjectM (..)
-    , emptyProjectUpdate
-    , newPaginationParam
-    , newProject
+    , updateProjectBuilder
+    , paginationParamBuilder
+    , createProjectBuilder
     )
 
 import Web.Todoist.Domain.Task
-    ( MoveTask (..)
+    ( MoveTask
     , NewTask (..)
     , Task (..)
     , TaskParam (..)
     , TodoistTaskM (..)
-    , newTaskParam
+    , taskParamBuilder
     )
 
 import Web.Todoist.Domain.Comment
@@ -179,9 +182,9 @@ import Web.Todoist.Domain.Comment
     , CommentParam (..)
     , CommentUpdate
     , TodoistCommentM (..)
-    , newComment
-    , newCommentParam
-    , newCommentUpdate
+    , newCommentBuilder
+    , commentParamBuilder
+    , updateCommentBuilder
     )
 
 import Web.Todoist.Domain.Section
@@ -191,9 +194,9 @@ import Web.Todoist.Domain.Section
     , SectionParam (..)
     , SectionUpdate
     , TodoistSectionM (..)
-    , emptySectionUpdate
-    , newSection
-    , newSectionParam
+    , updateSectionBuilder
+    , newSectionBuilder
+    , sectionParamBuilder
     )
 
 import Web.Todoist.Domain.Label
@@ -206,10 +209,12 @@ import Web.Todoist.Domain.Label
     , SharedLabelRemove
     , SharedLabelRename
     , TodoistLabelM (..)
-    , emptyLabelUpdate
-    , newLabel
-    , newLabelParam
-    , newSharedLabelParam
+    , updateLabelBuilder
+    , createLabelBuilder
+    , labelParamBuilder
+    , sharedLabelParamBuilder
+    , mkSharedLabelRename
+    , mkSharedLabelRemove
     )
 
 import Web.Todoist.Domain.Types
@@ -230,22 +235,23 @@ import Web.Todoist.Util.Builder
     , Initial
     , runBuilder
     , seed
-    , setAssigneeId
-    , setContent
-    , setDescription
-    , setDueDate
-    , setDueDatetime
-    , setDueLang
-    , setDueString
-    , setIsFavorite
-    , setLabels
-    , setName
-    , setOrder
-    , setParentId
-    , setPriority
-    , setProjectId
-    , setSectionId
-    , setTaskId
-    , setViewStyle
-    , setWorkspaceId
+    , withAssigneeId
+    , withColor
+    , withContent
+    , withDescription
+    , withDueDate
+    , withDueDatetime
+    , withDueLang
+    , withDueString
+    , withIsFavorite
+    , withLabels
+    , withName
+    , withOrder
+    , withParentId
+    , withPriority
+    , withProjectId
+    , withSectionId
+    , withTaskId
+    , withViewStyle
+    , withWorkspaceId
     )
