@@ -24,22 +24,22 @@ main = do
     let config = newTodoistConfig "your-api-token"
 
     -- Create a comment on a project
-    let projectComment = runBuilder (newComment "Great project!")
-                         (setProjectId "project-id-123")
+    let projectComment = runBuilder (newCommentBuilder "Great project!")
+                         (withProjectId "project-id-123")
     result <- todoist config (addComment projectComment)
 
     -- Create a comment on a task
-    let taskComment = runBuilder (newComment "Don't forget this!")
-                      (setTaskId "task-id-456")
+    let taskComment = runBuilder (newCommentBuilder "Don't forget this!")
+                      (withTaskId "task-id-456")
     result <- todoist config (addComment taskComment)
 
     -- Get all comments for a project with builder pattern
-    let params = runBuilder newCommentParam (setProjectId "project-id-123" <> setLimit 50)
+    let params = runBuilder commentParamBuilder (withProjectId "project-id-123" <> withLimit 50)
     comments <- todoist config (getComments params)
 
     -- Update a comment
-    let update = runBuilder (newCommentUpdate "Updated text!") mempty
-    updatedComment <- todoist config (updateComment commentId update)
+    let update = runBuilder (updateCommentBuilder "Updated text!") mempty
+    updatedComment <- todoist config (updateComment update commentId)
 @
 
 For more details on the Todoist Comments API, see:
@@ -55,12 +55,21 @@ module Web.Todoist.Domain.Comment
     , CommentParam (..)
 
       -- * Constructors
-    , newComment
-    , newCommentUpdate
-    , newCommentParam
+    , newCommentBuilder
+    , updateCommentBuilder
+    , commentParamBuilder
 
       -- * Type Class
     , TodoistCommentM (..)
+
+      -- * Lenses
+    , commentId
+    , commentContent
+    , commentPosterId
+    , commentPostedAt
+    , commentTaskId
+    , commentProjectId
+    , commentAttachment
     ) where
 
 import Web.Todoist.Internal.Types (FileAttachment, Params)
@@ -102,8 +111,10 @@ import Data.Text (Text)
 import qualified Data.Text as T
 import qualified Data.Tuple as L
 import GHC.Generics (Generic)
+import Lens.Micro (to)
 import Text.Show (Show (..))
 import Web.Todoist.Domain.Types (Attachment, Content (..), ProjectId (..), TaskId (..), Uid)
+import Web.Todoist.Lens (Getter)
 
 -- | Newtype wrapper for Comment ID
 newtype CommentId = CommentId {getCommentId :: Text}
@@ -129,6 +140,35 @@ data Comment = Comment
     }
     deriving (Show, Eq, Generic)
 
+-- | Lenses for Comment
+commentId :: Getter Comment CommentId
+commentId = to (\(Comment {_id = x}) -> x)
+{-# INLINE commentId #-}
+
+commentContent :: Getter Comment Content
+commentContent = to (\(Comment {_content = x}) -> x)
+{-# INLINE commentContent #-}
+
+commentPosterId :: Getter Comment (Maybe Uid)
+commentPosterId = to (\(Comment {_poster_id = x}) -> x)
+{-# INLINE commentPosterId #-}
+
+commentPostedAt :: Getter Comment (Maybe Uid)
+commentPostedAt = to (\(Comment {_posted_at = x}) -> x)
+{-# INLINE commentPostedAt #-}
+
+commentTaskId :: Getter Comment (Maybe TaskId)
+commentTaskId = to (\(Comment {_task_id = x}) -> x)
+{-# INLINE commentTaskId #-}
+
+commentProjectId :: Getter Comment (Maybe ProjectId)
+commentProjectId = to (\(Comment {_project_id = x}) -> x)
+{-# INLINE commentProjectId #-}
+
+commentAttachment :: Getter Comment (Maybe FileAttachment)
+commentAttachment = to (\(Comment {_attachment = x}) -> x)
+{-# INLINE commentAttachment #-}
+
 -- | Request body for creating a comment
 data CommentCreate = CommentCreate
     { _content :: Content
@@ -193,8 +233,8 @@ instance QueryParam CommentParam where
 {- | Constructor for CommentCreate
 Truncates content to 15000 characters (Todoist API limit)
 -}
-newComment :: Text -> Initial CommentCreate
-newComment content =
+newCommentBuilder :: Text -> Initial CommentCreate
+newCommentBuilder content =
     let truncated = T.take 15000 content
      in seed $
             CommentCreate
@@ -208,14 +248,14 @@ newComment content =
 {- | Constructor for CommentUpdate
 Truncates content to 15000 characters (Todoist API limit)
 -}
-newCommentUpdate :: Text -> Initial CommentUpdate
-newCommentUpdate content =
+updateCommentBuilder :: Text -> Initial CommentUpdate
+updateCommentBuilder content =
     let truncated = T.take 15000 content
      in seed $ CommentUpdate {_content = Just truncated}
 
 -- | Create new CommentParam for use with builder pattern
-newCommentParam :: Initial CommentParam
-newCommentParam =
+commentParamBuilder :: Initial CommentParam
+commentParamBuilder =
     seed $
         CommentParam
             { project_id = Nothing
@@ -242,7 +282,7 @@ class (Monad m) => TodoistCommentM m where
     getComment :: CommentId -> m Comment
 
     -- | Update a comment's content
-    updateComment :: CommentId -> CommentUpdate -> m Comment
+    updateComment :: CommentUpdate -> CommentId -> m Comment
 
     -- | Delete a comment
     deleteComment :: CommentId -> m ()
