@@ -24,11 +24,11 @@ main = do
     let config = newTodoistConfig "your-api-token"
 
     -- Create a section in a project
-    let newSec = runBuilder (newSection "To Do" "project-id-123") mempty
+    let newSec = runBuilder (newSectionBuilder "To Do" "project-id-123") mempty
     section <- todoist config (addSection newSec)
 
     -- Get all sections in a project with builder pattern
-    let params = runBuilder newSectionParam (setProjectId "project-id-123" <> setLimit 50)
+    let params = runBuilder sectionParamBuilder (withProjectId "project-id-123" <> withLimit 50)
     sections <- todoist config (getSections params)
 @
 
@@ -39,16 +39,23 @@ module Web.Todoist.Domain.Section
       Section (..)
     , SectionId (..)
     , SectionCreate
-    , SectionUpdate (..)
+    , SectionUpdate
     , SectionParam (..)
 
       -- * Type Class
     , TodoistSectionM (..)
 
       -- * Constructors
-    , newSection
-    , emptySectionUpdate
-    , newSectionParam
+    , newSectionBuilder
+    , updateSectionBuilder
+    , sectionParamBuilder
+
+      -- * Lenses
+    , sectionId
+    , sectionName
+    , sectionProjectId
+    , sectionIsCollapsed
+    , sectionOrder
     ) where
 
 import Data.Aeson
@@ -63,6 +70,8 @@ import Data.Bool (Bool (True))
 import Data.Text (Text)
 import qualified Data.Text as T
 import GHC.Generics (Generic)
+import Lens.Micro (to)
+import Web.Todoist.Lens (Getter)
 
 import qualified Data.Aeson as A
 import qualified Data.List as L
@@ -110,6 +119,27 @@ data Section = Section
     }
     deriving (Show, Generic)
 
+-- | Lenses for Section
+sectionId :: Getter Section SectionId
+sectionId = to (\(Section {_id = x}) -> x)
+{-# INLINE sectionId #-}
+
+sectionName :: Getter Section Name
+sectionName = to (\(Section {_name = x}) -> x)
+{-# INLINE sectionName #-}
+
+sectionProjectId :: Getter Section ProjectId
+sectionProjectId = to (\(Section {_project_id = x}) -> x)
+{-# INLINE sectionProjectId #-}
+
+sectionIsCollapsed :: Getter Section IsCollapsed
+sectionIsCollapsed = to (\(Section {_is_collapsed = x}) -> x)
+{-# INLINE sectionIsCollapsed #-}
+
+sectionOrder :: Getter Section Order
+sectionOrder = to (\(Section {_order = x}) -> x)
+{-# INLINE sectionOrder #-}
+
 -- | Request body for creating a new Section
 data SectionCreate = SectionCreate
     { _name :: Name
@@ -168,7 +198,7 @@ class (Monad m) => TodoistSectionM m where
     addSection :: SectionCreate -> m SectionId
 
     -- | Update a section
-    updateSection :: SectionId -> SectionUpdate -> m Section
+    updateSection :: SectionUpdate -> SectionId -> m Section
 
     -- | Delete a section (and all its tasks)
     deleteSection :: SectionId -> m ()
@@ -179,8 +209,8 @@ class (Monad m) => TodoistSectionM m where
     getSectionsPaginated :: SectionParam -> m ([Section], Maybe Text)
 
 -- | Smart constructor for creating a new section
-newSection :: Text -> Text -> Initial SectionCreate
-newSection name projectId =
+newSectionBuilder :: Text -> Text -> Initial SectionCreate
+newSectionBuilder name projectId =
     seed
         SectionCreate
             { _name = Name name
@@ -189,16 +219,16 @@ newSection name projectId =
             }
 
 -- | Empty section update for builder pattern
-emptySectionUpdate :: Initial SectionUpdate
-emptySectionUpdate =
+updateSectionBuilder :: Initial SectionUpdate
+updateSectionBuilder =
     seed
         SectionUpdate
             { _name = Nothing
             }
 
 -- | Create new SectionParam for use with builder pattern
-newSectionParam :: Initial SectionParam
-newSectionParam =
+sectionParamBuilder :: Initial SectionParam
+sectionParamBuilder =
     seed
         SectionParam
             { project_id = Nothing
