@@ -28,12 +28,12 @@ main = do
     let config = newTodoistConfig "your-api-token"
 
     -- Create a new task
-    let task = runBuilder (newTask "Buy groceries")
-               (setDescription "Milk, eggs, bread" <> setPriority 2)
-    taskId <- todoist config (addTask task)
+    let task = runBuilder (newTaskBuilder "Buy groceries")
+               (withDescription "Milk, eggs, bread" <> withPriority 2)
+    taskId <- todoist config (createTask task)
 
     -- Get all tasks with builder pattern
-    let params = runBuilder newTaskParam (setProjectId "project-123" <> setLimit 50)
+    let params = runBuilder taskParamBuilder (withProjectId "project-123" <> withLimit 50)
     tasks <- todoist config (getTasks params)
 
     -- Complete a task
@@ -50,8 +50,8 @@ module Web.Todoist.Domain.Task
     , Deadline (..)
     , Duration (..)
     , DurationUnit (..)
-    , NewTask (..) -- todo: remove child exports
-    , MoveTask (..)
+    , NewTask (..)
+    , MoveTask
     , AddTaskQuick
     , addTaskQuickText
     , CompletedTasksQueryParamAPI (..)
@@ -59,13 +59,78 @@ module Web.Todoist.Domain.Task
     , TaskFilter (..)
     , CompletedTasksQueryParam (..)
     , TaskCreate
-    , TaskPatch
-    , newTask
-    , newMoveTask
-    , emptyTaskPatch
-    , newTaskParam
-    , newTaskFilter
-    , newCompletedTasksQueryParam
+    , TaskUpdate
+    , newTaskBuilder
+    , moveTaskBuilder
+    , updateTaskBuilder
+    , taskParamBuilder
+    , filterTaskBuilder
+    , completedTasksQueryParamBuilder
+      -- * Lenses
+      -- ** Duration
+    , amount
+    , unit
+      -- ** Deadline
+    , deadlineDate
+    , deadlineLang
+      -- ** Due
+    , dueDate
+    , dueString
+    , dueLang
+    , dueIsRecurring
+    , dueTimezone
+      -- ** Task
+    , taskId
+    , taskContent
+    , taskDescription
+    , taskProjectId
+    , taskSectionId
+    , taskParentId
+    , taskLabels
+    , taskPriority
+    , taskDue
+    , taskDeadline
+    , taskDuration
+    , taskIsCollapsed
+    , taskOrder
+    , taskAssigneeId
+    , taskAssignerId
+    , taskCompletedAt
+    , taskCreatorId
+    , taskCreatedAt
+    , taskUpdatedAt
+      -- ** NewTask
+    , newTaskUserId
+    , newTaskId
+    , newTaskProjectId
+    , newTaskSectionId
+    , newTaskParentId
+    , newTaskAddedByUid
+    , newTaskAssignedByUid
+    , newTaskResponsibleUid
+    , newTaskLabels
+    , newTaskChecked
+    , newTaskIsDeleted
+    , newTaskAddedAt
+    , newTaskCompletedAt
+    , newTaskUpdatedAt
+    , newTaskPriority
+    , newTaskChildOrder
+    , newTaskContent
+    , newTaskDescription
+    , newTaskNoteCount
+    , newTaskDayOrder
+    , newTaskIsCollapsed
+      -- ** MoveTask
+    , moveTaskProjectId
+    , moveTaskSectionId
+    , moveTaskParentId
+      -- ** AddTaskQuick
+    , addTaskQuickTextLens
+    , addTaskQuickNote
+    , addTaskQuickReminder
+    , addTaskQuickAutoReminder
+    , addTaskQuickMeta
     ) where
 
 import Web.Todoist.Internal.Types (Params)
@@ -91,9 +156,7 @@ import Web.Todoist.Util.Builder
     , HasPriority (..)
     , HasProjectId (..)
     , HasSectionId (..)
-    -- , HasSince (..)
     , HasTaskIds (..)
-    -- , HasUntil (..)
     , Initial
     , seed
     )
@@ -120,16 +183,18 @@ import Data.Monoid ((<>))
 import Data.Text (Text)
 import qualified Data.Text
 import GHC.Generics (Generic)
+import Lens.Micro (to)
 import Text.Show (Show)
+import Web.Todoist.Lens (Getter)
 import Web.Todoist.Domain.Section (SectionId (..))
 import Web.Todoist.Domain.Types
     ( Content (..)
     , Description (..)
-    , IsCollapsed
+    , IsCollapsed (..)
     , Order (..)
     , ParentId (..)
     , ProjectId (..)
-    , TaskId
+    , TaskId (..)
     , Uid
     )
 
@@ -161,6 +226,15 @@ instance ToJSON Duration where
     toJSON :: Duration -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1}
 
+-- | Lenses for Duration
+amount :: Getter Duration Int
+amount = to _amount
+{-# INLINE amount #-}
+
+unit :: Getter Duration DurationUnit
+unit = to _unit
+{-# INLINE unit #-}
+
 -- | Deadline information for a task
 data Deadline = Deadline
     { _date :: Text
@@ -176,6 +250,15 @@ instance ToJSON Deadline where
     toJSON :: Deadline -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1}
 
+-- | Lenses for Deadline
+deadlineDate :: Getter Deadline Text
+deadlineDate = to (\(Deadline {_date = x}) -> x)
+{-# INLINE deadlineDate #-}
+
+deadlineLang :: Getter Deadline Text
+deadlineLang = to (\(Deadline {_lang = x}) -> x)
+{-# INLINE deadlineLang #-}
+
 -- | Due date information for a task
 data Due = Due
     { _date :: Text
@@ -194,6 +277,27 @@ instance ToJSON Due where
     toJSON :: Due -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1}
 
+-- | Lenses for Due
+dueDate :: Getter Due Text
+dueDate = to (\(Due {_date = x}) -> x)
+{-# INLINE dueDate #-}
+
+dueString :: Getter Due Text
+dueString = to (\(Due {_string = x}) -> x)
+{-# INLINE dueString #-}
+
+dueLang :: Getter Due Text
+dueLang = to (\(Due {_lang = x}) -> x)
+{-# INLINE dueLang #-}
+
+dueIsRecurring :: Getter Due Bool
+dueIsRecurring = to (\(Due {_is_recurring = x}) -> x)
+{-# INLINE dueIsRecurring #-}
+
+dueTimezone :: Getter Due (Maybe Text)
+dueTimezone = to (\(Due {_timezone = x}) -> x)
+{-# INLINE dueTimezone #-}
+
 {- | Task domain type representing a Todoist task
 
 Contains all task metadata including content, project/section assignment,
@@ -231,6 +335,83 @@ instance ToJSON Task where
     toJSON :: Task -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1}
 
+-- | Lenses for Task
+taskId :: Getter Task TaskId
+taskId = to (\(Task {_id = x}) -> x)
+{-# INLINE taskId #-}
+
+taskContent :: Getter Task Content
+taskContent = to (\(Task {_content = x}) -> x)
+{-# INLINE taskContent #-}
+
+taskDescription :: Getter Task Description
+taskDescription = to (\(Task {_description = x}) -> x)
+{-# INLINE taskDescription #-}
+
+taskProjectId :: Getter Task ProjectId
+taskProjectId = to (\(Task {_project_id = x}) -> x)
+{-# INLINE taskProjectId #-}
+
+taskSectionId :: Getter Task (Maybe SectionId)
+taskSectionId = to (\(Task {_section_id = x}) -> x)
+{-# INLINE taskSectionId #-}
+
+taskParentId :: Getter Task (Maybe ParentId)
+taskParentId = to (\(Task {_parent_id = x}) -> x)
+{-# INLINE taskParentId #-}
+
+taskLabels :: Getter Task [Text]
+taskLabels = to (\(Task {_labels = x}) -> x)
+{-# INLINE taskLabels #-}
+
+taskPriority :: Getter Task Int
+taskPriority = to (\(Task {_priority = x}) -> x)
+{-# INLINE taskPriority #-}
+
+taskDue :: Getter Task (Maybe Due)
+taskDue = to (\(Task {_due = x}) -> x)
+{-# INLINE taskDue #-}
+
+taskDeadline :: Getter Task (Maybe Deadline)
+taskDeadline = to (\(Task {_deadline = x}) -> x)
+{-# INLINE taskDeadline #-}
+
+taskDuration :: Getter Task (Maybe Duration)
+taskDuration = to (\(Task {_duration = x}) -> x)
+{-# INLINE taskDuration #-}
+
+taskIsCollapsed :: Getter Task IsCollapsed
+taskIsCollapsed = to (\(Task {_is_collapsed = x}) -> x)
+{-# INLINE taskIsCollapsed #-}
+
+taskOrder :: Getter Task Order
+taskOrder = to (\(Task {_order = x}) -> x)
+{-# INLINE taskOrder #-}
+
+taskAssigneeId :: Getter Task (Maybe Uid)
+taskAssigneeId = to (\(Task {_assignee_id = x}) -> x)
+{-# INLINE taskAssigneeId #-}
+
+taskAssignerId :: Getter Task (Maybe Uid)
+taskAssignerId = to (\(Task {_assigner_id = x}) -> x)
+{-# INLINE taskAssignerId #-}
+
+taskCompletedAt :: Getter Task (Maybe Text)
+taskCompletedAt = to (\(Task {_completed_at = x}) -> x)
+{-# INLINE taskCompletedAt #-}
+
+taskCreatorId :: Getter Task Uid
+taskCreatorId = to (\(Task {_creator_id = x}) -> x)
+{-# INLINE taskCreatorId #-}
+
+taskCreatedAt :: Getter Task Text
+taskCreatedAt = to (\(Task {_created_at = x}) -> x)
+{-# INLINE taskCreatedAt #-}
+
+taskUpdatedAt :: Getter Task Text
+taskUpdatedAt = to (\(Task {_updated_at = x}) -> x)
+{-# INLINE taskUpdatedAt #-}
+
 data NewTask = NewTask
     { _user_id :: Text
     , _id :: TaskId
@@ -264,6 +445,91 @@ instance ToJSON NewTask where
     toJSON :: NewTask -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1}
 
+-- | Lenses for NewTask
+newTaskUserId :: Getter NewTask Text
+newTaskUserId = to (\(NewTask {_user_id = x}) -> x)
+{-# INLINE newTaskUserId #-}
+
+newTaskId :: Getter NewTask TaskId
+newTaskId = to (\(NewTask {_id = x}) -> x)
+{-# INLINE newTaskId #-}
+
+newTaskProjectId :: Getter NewTask ProjectId
+newTaskProjectId = to (\(NewTask {_project_id = x}) -> x)
+{-# INLINE newTaskProjectId #-}
+
+newTaskSectionId :: Getter NewTask (Maybe SectionId)
+newTaskSectionId = to (\(NewTask {_section_id = x}) -> x)
+{-# INLINE newTaskSectionId #-}
+
+newTaskParentId :: Getter NewTask (Maybe ParentId)
+newTaskParentId = to (\(NewTask {_parent_id = x}) -> x)
+{-# INLINE newTaskParentId #-}
+
+newTaskAddedByUid :: Getter NewTask (Maybe Uid)
+newTaskAddedByUid = to (\(NewTask {_added_by_uid = x}) -> x)
+{-# INLINE newTaskAddedByUid #-}
+
+newTaskAssignedByUid :: Getter NewTask (Maybe Uid)
+newTaskAssignedByUid = to (\(NewTask {_assigned_by_uid = x}) -> x)
+{-# INLINE newTaskAssignedByUid #-}
+
+newTaskResponsibleUid :: Getter NewTask (Maybe Uid)
+newTaskResponsibleUid = to (\(NewTask {_responsible_uid = x}) -> x)
+{-# INLINE newTaskResponsibleUid #-}
+
+newTaskLabels :: Getter NewTask [Text]
+newTaskLabels = to (\(NewTask {_labels = x}) -> x)
+{-# INLINE newTaskLabels #-}
+
+newTaskChecked :: Getter NewTask Bool
+newTaskChecked = to (\(NewTask {_checked = x}) -> x)
+{-# INLINE newTaskChecked #-}
+
+newTaskIsDeleted :: Getter NewTask Bool
+newTaskIsDeleted = to (\(NewTask {_is_deleted = x}) -> x)
+{-# INLINE newTaskIsDeleted #-}
+
+newTaskAddedAt :: Getter NewTask (Maybe Text)
+newTaskAddedAt = to (\(NewTask {_added_at = x}) -> x)
+{-# INLINE newTaskAddedAt #-}
+
+newTaskCompletedAt :: Getter NewTask (Maybe Text)
+newTaskCompletedAt = to (\(NewTask {_completed_at = x}) -> x)
+{-# INLINE newTaskCompletedAt #-}
+
+newTaskUpdatedAt :: Getter NewTask (Maybe Text)
+newTaskUpdatedAt = to (\(NewTask {_updated_at = x}) -> x)
+{-# INLINE newTaskUpdatedAt #-}
+
+newTaskPriority :: Getter NewTask Int
+newTaskPriority = to (\(NewTask {_priority = x}) -> x)
+{-# INLINE newTaskPriority #-}
+
+newTaskChildOrder :: Getter NewTask Order
+newTaskChildOrder = to (\(NewTask {_child_order = x}) -> x)
+{-# INLINE newTaskChildOrder #-}
+
+newTaskContent :: Getter NewTask Content
+newTaskContent = to (\(NewTask {_content = x}) -> x)
+{-# INLINE newTaskContent #-}
+
+newTaskDescription :: Getter NewTask Description
+newTaskDescription = to (\(NewTask {_description = x}) -> x)
+{-# INLINE newTaskDescription #-}
+
+newTaskNoteCount :: Getter NewTask Int
+newTaskNoteCount = to (\(NewTask {_note_count = x}) -> x)
+{-# INLINE newTaskNoteCount #-}
+
+newTaskDayOrder :: Getter NewTask Order
+newTaskDayOrder = to (\(NewTask {_day_order = x}) -> x)
+{-# INLINE newTaskDayOrder #-}
+
+newTaskIsCollapsed :: Getter NewTask IsCollapsed
+newTaskIsCollapsed = to (\(NewTask {_is_collapsed = x}) -> x)
+{-# INLINE newTaskIsCollapsed #-}
+
 data MoveTask = MoveTask
     { _project_id :: Maybe ProjectId
     , _section_id :: Maybe SectionId
@@ -279,8 +545,22 @@ instance FromJSON MoveTask where
     parseJSON :: Value -> Parser MoveTask
     parseJSON = genericParseJSON defaultOptions {fieldLabelModifier = L.drop 1}
 
-newMoveTask :: Initial MoveTask
-newMoveTask =
+-- | Lenses for MoveTask
+moveTaskProjectId :: Getter MoveTask (Maybe ProjectId)
+moveTaskProjectId = to (\(MoveTask {_project_id = x}) -> x)
+{-# INLINE moveTaskProjectId #-}
+
+moveTaskSectionId :: Getter MoveTask (Maybe SectionId)
+moveTaskSectionId = to (\(MoveTask {_section_id = x}) -> x)
+{-# INLINE moveTaskSectionId #-}
+
+moveTaskParentId :: Getter MoveTask (Maybe ParentId)
+moveTaskParentId = to (\(MoveTask {_parent_id = x}) -> x)
+{-# INLINE moveTaskParentId #-}
+
+-- | Create empty MoveTask for use with builder pattern
+moveTaskBuilder :: Initial MoveTask
+moveTaskBuilder =
     seed
         MoveTask
             { _project_id = Nothing
@@ -309,6 +589,27 @@ data AddTaskQuick = AddTaskQuick
     }
     deriving (Show, Generic, FromJSON, ToJSON)
 
+-- | Lenses for AddTaskQuick
+addTaskQuickTextLens :: Getter AddTaskQuick Text
+addTaskQuickTextLens = to (\(AddTaskQuick {_text = x}) -> x)
+{-# INLINE addTaskQuickTextLens #-}
+
+addTaskQuickNote :: Getter AddTaskQuick (Maybe Text)
+addTaskQuickNote = to (\(AddTaskQuick {_note = x}) -> x)
+{-# INLINE addTaskQuickNote #-}
+
+addTaskQuickReminder :: Getter AddTaskQuick (Maybe Text)
+addTaskQuickReminder = to (\(AddTaskQuick {_reminder = x}) -> x)
+{-# INLINE addTaskQuickReminder #-}
+
+addTaskQuickAutoReminder :: Getter AddTaskQuick Bool
+addTaskQuickAutoReminder = to (\(AddTaskQuick {_auto_reminder = x}) -> x)
+{-# INLINE addTaskQuickAutoReminder #-}
+
+addTaskQuickMeta :: Getter AddTaskQuick Bool
+addTaskQuickMeta = to (\(AddTaskQuick {_meta = x}) -> x)
+{-# INLINE addTaskQuickMeta #-}
+
 addTaskQuickText :: Text -> AddTaskQuick
 addTaskQuickText text =
     AddTaskQuick
@@ -321,7 +622,7 @@ addTaskQuickText text =
 
 {- | Request body for creating a new task
 
-Only content is required. Use 'newTask' with the builder pattern for
+Only content is required. Use 'newTaskBuilder' with the builder pattern for
 ergonomic construction of tasks with optional fields.
 -}
 data TaskCreate = TaskCreate
@@ -348,8 +649,9 @@ instance ToJSON TaskCreate where
     toJSON :: TaskCreate -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1, omitNothingFields = True}
 
-newTask :: Text -> Initial TaskCreate
-newTask content =
+-- | Create new TaskCreate with required content parameter
+newTaskBuilder :: Text -> Initial TaskCreate
+newTaskBuilder content =
     seed
         TaskCreate
             { _content = Content content
@@ -437,9 +739,9 @@ instance HasProjectId TaskCreate where
 {- | Request body for updating an existing task (partial updates)
 
 All fields are optional (using Maybe). Only provided fields will be updated.
-Use 'emptyTaskPatch' with the builder pattern for updates.
+Use 'updateTaskBuilder' with the builder pattern for updates.
 -}
-data TaskPatch = TaskPatch
+data TaskUpdate = TaskUpdate
     { _content :: Maybe Content
     , _description :: Maybe Description
     , _labels :: Maybe [Text]
@@ -456,10 +758,10 @@ data TaskPatch = TaskPatch
     }
     deriving (Show, Generic)
 
-emptyTaskPatch :: Initial TaskPatch
-emptyTaskPatch =
+updateTaskBuilder :: Initial TaskUpdate
+updateTaskBuilder =
     seed
-        TaskPatch
+        TaskUpdate
             { _content = Nothing
             , _description = Nothing
             , _labels = Nothing
@@ -475,57 +777,57 @@ emptyTaskPatch =
             , _deadline_lang = Nothing
             }
 
-instance ToJSON TaskPatch where
-    toJSON :: TaskPatch -> Value
+instance ToJSON TaskUpdate where
+    toJSON :: TaskUpdate -> Value
     toJSON = genericToJSON defaultOptions {fieldLabelModifier = L.drop 1, omitNothingFields = True}
 
-instance HasDescription TaskPatch where
-    hasDescription :: Text -> TaskPatch -> TaskPatch
-    hasDescription desc TaskPatch {..} = TaskPatch {_description = Just (Description desc), ..}
+instance HasDescription TaskUpdate where
+    hasDescription :: Text -> TaskUpdate -> TaskUpdate
+    hasDescription desc TaskUpdate {..} = TaskUpdate {_description = Just (Description desc), ..}
 
-instance HasContent TaskPatch where
-    hasContent :: Text -> TaskPatch -> TaskPatch
-    hasContent content TaskPatch {..} = TaskPatch {_content = Just (Content content), ..}
+instance HasContent TaskUpdate where
+    hasContent :: Text -> TaskUpdate -> TaskUpdate
+    hasContent content TaskUpdate {..} = TaskUpdate {_content = Just (Content content), ..}
 
-instance HasLabels TaskPatch where
-    hasLabels :: [Text] -> TaskPatch -> TaskPatch
-    hasLabels labels TaskPatch {..} = TaskPatch {_labels = Just labels, ..}
+instance HasLabels TaskUpdate where
+    hasLabels :: [Text] -> TaskUpdate -> TaskUpdate
+    hasLabels labels TaskUpdate {..} = TaskUpdate {_labels = Just labels, ..}
 
-instance HasPriority TaskPatch where
-    hasPriority :: Int -> TaskPatch -> TaskPatch
-    hasPriority priority TaskPatch {..} = TaskPatch {_priority = Just priority, ..}
+instance HasPriority TaskUpdate where
+    hasPriority :: Int -> TaskUpdate -> TaskUpdate
+    hasPriority priority TaskUpdate {..} = TaskUpdate {_priority = Just priority, ..}
 
-instance HasDueString TaskPatch where
-    hasDueString :: Text -> TaskPatch -> TaskPatch
-    hasDueString dueStr TaskPatch {..} = TaskPatch {_due_string = Just dueStr, ..}
+instance HasDueString TaskUpdate where
+    hasDueString :: Text -> TaskUpdate -> TaskUpdate
+    hasDueString dueStr TaskUpdate {..} = TaskUpdate {_due_string = Just dueStr, ..}
 
-instance HasDueDate TaskPatch where
-    hasDueDate :: Text -> TaskPatch -> TaskPatch
-    hasDueDate dueDate TaskPatch {..} = TaskPatch {_due_date = Just dueDate, ..}
+instance HasDueDate TaskUpdate where
+    hasDueDate :: Text -> TaskUpdate -> TaskUpdate
+    hasDueDate dueDate TaskUpdate {..} = TaskUpdate {_due_date = Just dueDate, ..}
 
-instance HasDueDatetime TaskPatch where
-    hasDueDatetime :: Text -> TaskPatch -> TaskPatch
-    hasDueDatetime dueDatetime TaskPatch {..} = TaskPatch {_due_datetime = Just dueDatetime, ..}
+instance HasDueDatetime TaskUpdate where
+    hasDueDatetime :: Text -> TaskUpdate -> TaskUpdate
+    hasDueDatetime dueDatetime TaskUpdate {..} = TaskUpdate {_due_datetime = Just dueDatetime, ..}
 
-instance HasDueLang TaskPatch where
-    hasDueLang :: Text -> TaskPatch -> TaskPatch
-    hasDueLang dueLang TaskPatch {..} = TaskPatch {_due_lang = Just dueLang, ..}
+instance HasDueLang TaskUpdate where
+    hasDueLang :: Text -> TaskUpdate -> TaskUpdate
+    hasDueLang dueLang TaskUpdate {..} = TaskUpdate {_due_lang = Just dueLang, ..}
 
-instance HasAssigneeId TaskPatch where
-    hasAssigneeId :: Int -> TaskPatch -> TaskPatch
-    hasAssigneeId aid TaskPatch {..} = TaskPatch {_assignee_id = Just aid, ..}
+instance HasAssigneeId TaskUpdate where
+    hasAssigneeId :: Int -> TaskUpdate -> TaskUpdate
+    hasAssigneeId aid TaskUpdate {..} = TaskUpdate {_assignee_id = Just aid, ..}
 
-instance HasDuration TaskPatch where
-    hasDuration :: Int -> TaskPatch -> TaskPatch
-    hasDuration duration TaskPatch {..} = TaskPatch {_duration = Just duration, ..}
+instance HasDuration TaskUpdate where
+    hasDuration :: Int -> TaskUpdate -> TaskUpdate
+    hasDuration duration TaskUpdate {..} = TaskUpdate {_duration = Just duration, ..}
 
-instance HasDurationUnit TaskPatch where
-    hasDurationUnit :: Text -> TaskPatch -> TaskPatch
-    hasDurationUnit durationUnit TaskPatch {..} = TaskPatch {_duration_unit = Just durationUnit, ..}
+instance HasDurationUnit TaskUpdate where
+    hasDurationUnit :: Text -> TaskUpdate -> TaskUpdate
+    hasDurationUnit durationUnit TaskUpdate {..} = TaskUpdate {_duration_unit = Just durationUnit, ..}
 
-instance HasDeadlineDate TaskPatch where
-    hasDeadlineDate :: Text -> TaskPatch -> TaskPatch
-    hasDeadlineDate deadlineDate TaskPatch {..} = TaskPatch {_deadline_date = Just deadlineDate, ..}
+instance HasDeadlineDate TaskUpdate where
+    hasDeadlineDate :: Text -> TaskUpdate -> TaskUpdate
+    hasDeadlineDate deadlineDate TaskUpdate {..} = TaskUpdate {_deadline_date = Just deadlineDate, ..}
 
 {- | Internal type for parsing completed tasks API response
 The API returns full task objects, not just IDs
@@ -551,10 +853,10 @@ class (Monad m) => TodoistTaskM m where
     getTask :: TaskId -> m Task
 
     -- | Create a new task
-    addTask :: TaskCreate -> m NewTask -- todo: should return Task; TaskCreate should be named NewTask
+    createTask :: TaskCreate -> m NewTask -- todo: should return Task; TaskCreate should be named NewTask
 
     -- | Update an existing task with partial changes
-    updateTask :: TaskPatch -> TaskId -> m NewTask -- todo: should return Task
+    updateTask :: TaskUpdate -> TaskId -> m NewTask -- todo: should return Task
 
     -- | Mark a task as completed
     closeTask :: TaskId -> m ()
@@ -633,8 +935,8 @@ instance QueryParam TaskFilter where
             <> maybe [] (\p -> [("limit", Data.Text.show p)]) limit
 
 -- | Create new TaskFilter with required query parameter
-newTaskFilter :: Text -> Initial TaskFilter
-newTaskFilter query =
+filterTaskBuilder :: Text -> Initial TaskFilter
+filterTaskBuilder query =
     seed
         TaskFilter
             { query
@@ -673,8 +975,8 @@ instance QueryParam CompletedTasksQueryParam where
             <> [("limit", Data.Text.show limit)]
 
 -- | Create new CompletedTasksQueryParam with required since/until parameters
-newCompletedTasksQueryParam :: Text -> Text -> Initial CompletedTasksQueryParam
-newCompletedTasksQueryParam since until =
+completedTasksQueryParamBuilder :: Text -> Text -> Initial CompletedTasksQueryParam
+completedTasksQueryParamBuilder since until =
     seed
         CompletedTasksQueryParam
             { since
@@ -689,9 +991,9 @@ newCompletedTasksQueryParam since until =
             , limit = 50
             }
 
--- | Create new TaskParam for use with builder pattern
-newTaskParam :: Initial TaskParam
-newTaskParam =
+-- | Create empty TaskParam for use with builder pattern
+taskParamBuilder :: Initial TaskParam
+taskParamBuilder =
     seed
         TaskParam
             { project_id = Nothing
