@@ -61,13 +61,12 @@ module Web.Todoist.TestHelpers
     , sampleSharedLabelsJson
     ) where
 
-import Web.Todoist.Util.Builder (runBuilder, setDescription)
 import Web.Todoist.Domain.Comment
     ( Comment (..)
     , CommentCreate
     , CommentId (..)
     , Content (..)
-    , newComment
+    , newCommentBuilder
     )
 import Web.Todoist.Domain.Label
     ( Label (..)
@@ -80,15 +79,17 @@ import Web.Todoist.Domain.Project
     , IsShared (..)
     , Project (..)
     , ProjectCreate
-    , ProjectUpdate (..)
-    , newProject
+    , ProjectUpdate
+    , createProjectBuilder
+    , updateProjectBuilder
     )
 import Web.Todoist.Domain.Section
     ( Section (..)
     , SectionCreate
     , SectionId (..)
-    , SectionUpdate (..)
-    , newSection
+    , SectionUpdate
+    , newSectionBuilder
+    , updateSectionBuilder
     )
 import Web.Todoist.Domain.Task
     ( Deadline (..)
@@ -132,13 +133,14 @@ import Web.Todoist.Internal.Types
     , UpdatedAt (..)
     )
 import qualified Web.Todoist.Internal.Types as Internal
+import Web.Todoist.Util.Builder (runBuilder, withColor, withDescription, withName, withIsFavorite, withViewStyle)
 
 import Data.Bool (Bool (..))
 import Data.ByteString.Lazy (ByteString)
 import qualified Data.ByteString.Lazy.Char8 as BSL
 import Data.Function (($))
 import Data.Maybe (Maybe (..))
-import Data.Monoid (mempty)
+import Data.Monoid (mempty, (<>))
 
 -- | Sample ProjectId for testing
 sampleProjectId :: ProjectId
@@ -282,7 +284,7 @@ sampleCollaboratorsJson =
 
 -- | Sample ProjectCreate
 sampleProjectCreate :: ProjectCreate
-sampleProjectCreate = runBuilder (newProject "New Project") (setDescription "A new project to be created")
+sampleProjectCreate = runBuilder (createProjectBuilder "New Project") (withDescription "A new project to be created")
 
 -- | JSON representation of ProjectCreate (for serialization test)
 sampleProjectCreateJson :: ByteString
@@ -295,14 +297,7 @@ sampleProjectCreateJson =
 
 -- | Sample ProjectUpdate for testing
 sampleProjectUpdate :: ProjectUpdate
-sampleProjectUpdate =
-    ProjectUpdate
-        { _name = Just (Name "Updated Project Name")
-        , _description = Just (Description "Updated description")
-        , _color = Just (Color "red")
-        , _is_favorite = Just (IsFavorite True)
-        , _view_style = Just List
-        }
+sampleProjectUpdate = runBuilder updateProjectBuilder (withName "Updated Project Name" <> withDescription "Updated description" <> withColor "red" <> withIsFavorite True <> withViewStyle List)
 
 -- | JSON representation of ProjectUpdate
 sampleProjectUpdateJson :: ByteString
@@ -318,14 +313,7 @@ sampleProjectUpdateJson =
 
 -- | Sample ProjectUpdate with only some fields (partial update)
 samplePartialProjectUpdate :: ProjectUpdate
-samplePartialProjectUpdate =
-    ProjectUpdate
-        { _name = Just (Name "New Name")
-        , _description = Nothing
-        , _color = Nothing
-        , _is_favorite = Just (IsFavorite True)
-        , _view_style = Nothing
-        }
+samplePartialProjectUpdate = runBuilder updateProjectBuilder (withName "New Name" <> withIsFavorite True)
 
 -- | JSON representation of partial ProjectUpdate
 samplePartialProjectUpdateJson :: ByteString
@@ -720,7 +708,7 @@ sampleCommentResponseWithAttachmentJson =
 sampleCommentCreate :: CommentCreate
 sampleCommentCreate =
     runBuilder
-        (newComment "New comment")
+        (newCommentBuilder "New comment")
         mempty
 
 -- ===== Section Fixtures =====
@@ -777,14 +765,11 @@ sampleSection =
 
 -- | Sample SectionCreate
 sampleSectionCreate :: SectionCreate
-sampleSectionCreate = runBuilder (newSection "New Section" "project789") mempty
+sampleSectionCreate = runBuilder (newSectionBuilder "New Section" "project789") mempty
 
 -- | Sample SectionUpdate
 sampleSectionUpdate :: SectionUpdate
-sampleSectionUpdate =
-    SectionUpdate
-        { _name = Just (Name "Updated Section")
-        }
+sampleSectionUpdate = runBuilder updateSectionBuilder (withName "Updated Section")
 
 -- | JSON for TodoistReturn [SectionResponse] (getSections response)
 sampleSectionsJson :: ByteString
